camelot.camelot.view.proxy

Package camelot :: Package camelot :: Package view :: Package proxy |
[hide private]
[frames] | no frames]

# Package proxy

source code

Proxy objects for the model that live in the GUI thread and are able to respond immediately. They do so by keeping a local copy of the data of the real model

We take copies of the data in the elixir model, because accessing an attribute on the model, might cause an sql query which might take a long time, and might freeze the gui

Submodules | [hide private]
camelot.camelot.view.proxy.collection_proxy: Proxy representing a collection of entities that live in the model thread. camelot.camelot.view.proxy.queryproxy: Proxies representing the results of a query